#  tests for pbkdf2-1.3-py310h9f7ea03_1 (this is a generated file);
print('===== testing package: pbkdf2-1.3-py310h9f7ea03_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
from pbkdf2 import crypt, PBKDF2

print(crypt("secret"))
#  --- run_test.py (end) ---

print('===== pbkdf2-1.3-py310h9f7ea03_1 OK =====');
